@@ -2,6 +2,7 @@ import argparse
 import importlib
 import shutil
 import sys
+from pathlib import Path
 from importlib.metadata import Distribution, distribution, packages_distributions
 from typing import Iterable, Optional
 import json
@@ -145,7 +146,7 @@ def main():
         importlib.import_module(module_name)
     details = get_registered()
     setup = dist.metadata
-    command = entrypoint_of(dist)
+    command = Path(shutil.which(entrypoint_of(dist)))
     info = {
         'type': details.type,
         'parameters': serialize(details.parser),
@@ -160,8 +161,8 @@ def main():
 
         # ChRIS_ultron_backEnd version 2.8.1 requires these three to be defined
         # https://github.com/FNNDSC/ChRIS_ultron_backEnd/blob/fd38ae519dd1baf59c27677eb5a8ba774dc5f198/chris_backend/plugins/models.py#L174-L176
-        'selfpath': shutil.which(command),
-        'selfexec': command,
+        'selfpath': str(command.parent),
+        'selfexec': str(command.name),
         'execshell': sys.executable,
 
         'min_number_of_workers': details.min_number_of_workers,
